class GoTask < Formula
  desc "Task is a task runner/build tool that aims to be simpler and easier to use"
  homepage "https://taskfile.dev/"
  url "https://github.com/go-task/task/archive/refs/tags/v3.38.0.tar.gz"
  sha256 "09d597ed0618fd57dae944b61efa474f522f8d05d7ebeb0bc282cb5292b1d085"
  license "MIT"
  head "https://github.com/go-task/task.git", branch: "main"

  depends_on "go" => :build

  conflicts_with "task", because: "both install `task` binaries"

  # Fix ldflags for --version
  patch do
    url "https://github.com/go-task/task/commit/9ee4f21d62382714ac829df6f9bbf1637406eb5b.patch?full_index=1"
    sha256 "166c8150416568b34f900c87f0d40eba715d04cc41b780aa6393ee2532b422a2"
  end

  def install
    ldflags = %W[
      -s -w
      -X github.com/go-task/task/v3/internal/version.version=#{version}
    ]
    system "go", "build", *std_go_args(ldflags:, output: bin/"task"), "./cmd/task"
    bash_completion.install "completion/bash/task.bash" => "task"
    zsh_completion.install "completion/zsh/_task" => "_task"
    fish_completion.install "completion/fish/task.fish"
  end

  test do
    output = shell_output("#{bin}/task --version")
    assert_match "Task version: #{version}", output

    (testpath/"Taskfile.yml").write <<~EOS
      version: '3'

      tasks:
        test:
          cmds:
            - echo 'Testing Taskfile'
    EOS

    output = shell_output("#{bin}/task --silent test")
    assert_match "Testing Taskfile", output
  end
end
